..
    This file is part of Invenio.
    Copyright (C) 2015-2019 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Changes
=======

Version 1.3.3 (released 2023-10-12)

- Adds `LOGGING_SENTRY_INIT_KWARGS` to allow extra config on sentry initialization

Version 1.3.2 (released 2022-02-28)

- Fix dependency graph issue.

Version 1.3.1 (released 2022-02-16)

- Adds support for logging SQL queries and Redis calls to Sentry.

Version 1.3.0 (released 2020-03-12)

- drop Python 2.7 support
- change Flask dependency to invenio-base

Version 1.2.1 (released 2020-01-22)

- increased minimal six version
- changed documentation stale urls

Version 1.2.0 (released 2019-08-02)

Version 1.1.1 (released 2019-06-19)

- Fixed incorrect warnings logging by Sentry.
- Fixed unused config variables for Sentry.

Version 1.1.0 (released 2018-12-14)

Version 1.0.0 (released 2018-03-23)

- Initial public release.
